package com.example.gestionstagesbackend.controllers;

import com.example.gestionstagesbackend.model.Enterprise;
import com.example.gestionstagesbackend.services.EnterpriseService;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/api/enterprises")
@CrossOrigin(origins = "http://localhost:3000", allowCredentials = "true")
public class EnterpriseController {

    private final EnterpriseService enterpriseService;

    public EnterpriseController(EnterpriseService enterpriseService) {
        this.enterpriseService = enterpriseService;
    }

    @PostMapping("/add")
    public ResponseEntity<Enterprise> createEnterprise(@RequestBody Enterprise enterprise) {
        System.out.println("Received POST request: " + enterprise.getName() + ", " + enterprise.getAddress());

        Enterprise savedEnterprise = enterpriseService.saveEnterprise(enterprise);

        System.out.println("Response sent with Enterprise ID: " + savedEnterprise.getId());

        return ResponseEntity.ok(savedEnterprise);
    }

    @GetMapping
    public ResponseEntity<List<Enterprise>> getAllEnterprises() {
        System.out.println("🔵 Fetching all enterprises...");
        return ResponseEntity.ok(enterpriseService.getAllEnterprises());
    }

    @GetMapping("/{id}")
    public ResponseEntity<Enterprise> getEnterpriseById(@PathVariable Long id) {
        System.out.println("Fetching enterprise with ID: " + id);
        return enterpriseService.getEnterpriseById(id)
                .map(ResponseEntity::ok)
                .orElse(ResponseEntity.notFound().build());
    }

    @DeleteMapping("/delete/{id}")
    public ResponseEntity<Void> deleteEnterprise(@PathVariable Long id) {
        System.out.println("Deleting enterprise with ID: " + id);
        enterpriseService.deleteEnterprise(id);
        return ResponseEntity.noContent().build();
    }

    @PutMapping("/update/{id}")
    public ResponseEntity<?> updateEnterprise(@PathVariable Long id, @RequestBody Enterprise updatedEnterprise) {
        Optional<Enterprise> optionalEnterprise = enterpriseService.getEnterpriseById(id);

        if (optionalEnterprise.isPresent()) {
            Enterprise existingEnterprise = optionalEnterprise.get();
            existingEnterprise.setName(updatedEnterprise.getName());
            existingEnterprise.setAddress(updatedEnterprise.getAddress());

            Enterprise savedEnterprise = enterpriseService.saveEnterprise(existingEnterprise);
            return ResponseEntity.ok(savedEnterprise);
        } else {
            return ResponseEntity.notFound().build();
        }
    }

}
