package com.example.gestionstagesbackend.controllers;

import com.example.gestionstagesbackend.model.Stage;
import com.example.gestionstagesbackend.model.Enterprise;
import com.example.gestionstagesbackend.services.StageService;
import com.example.gestionstagesbackend.services.EnterpriseService;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/api/stages")
@CrossOrigin(origins = "http://localhost:3000", allowCredentials = "true")
public class StageController {
    private final StageService stageService;
    private final EnterpriseService enterpriseService;

    public StageController(StageService stageService, EnterpriseService enterpriseService) {
        this.stageService = stageService;
        this.enterpriseService = enterpriseService;
    }

    //@PreAuthorize("hasRole('ROLE_ENTREPRISE') or hasRole('ROLE_ADMIN')")
    @PostMapping("/add")
    public ResponseEntity<?> createStage(@RequestBody Stage stage) {
        if (stage.getEnterprise() == null || stage.getEnterprise().getId() == null) {
            return ResponseEntity.badRequest().body("Enterprise ID is required");
        }

        Optional<Enterprise> enterprise = enterpriseService.getEnterpriseById(stage.getEnterprise().getId());

        if (enterprise.isEmpty()) {
            return ResponseEntity.badRequest().body("Enterprise not found");
        }

        stage.setEnterprise(enterprise.get());
        Stage savedStage = stageService.saveStage(stage);

        // Fetch the saved stage with enterprise details included
        Optional<Stage> fullStage = stageService.getStageById(savedStage.getId());

        return fullStage.map(ResponseEntity::ok).orElse(ResponseEntity.ok(savedStage));
    }

    //@PreAuthorize("hasRole('ROLE_SUPERVISEUR') or hasRole('ROLE_ETUDIANT') or hasRole('ROLE_ADMIN')")
    @GetMapping
    public ResponseEntity<List<Stage>> getAllStages() {
        return ResponseEntity.ok(stageService.getAllStages());
    }
    @GetMapping("/{id}")
    public ResponseEntity<Stage> getStageById(@PathVariable Long id) {
        Optional<Stage> optionalStage = stageService.getStageById(id);

        if (optionalStage.isPresent()) {
            Stage stage = optionalStage.get();
            stage.getEnterprise().getId(); // Ensure Enterprise ID is included
            return ResponseEntity.ok(stage);
        } else {
            return ResponseEntity.notFound().build();
        }
    }


    //@PreAuthorize("hasRole('ROLE_ENTREPRISE') or hasRole('ROLE_ADMIN')")
    @PutMapping("/update/{id}")
    public ResponseEntity<?> updateStage(@PathVariable Long id, @RequestBody Stage updatedStage) {
        Optional<Stage> optionalStage = stageService.getStageById(id);

        if (optionalStage.isPresent()) {
            Stage existingStage = optionalStage.get();
            existingStage.setName(updatedStage.getName());
            existingStage.setDescription(updatedStage.getDescription());

            if (updatedStage.getEnterprise() != null && updatedStage.getEnterprise().getId() != null) {
                Optional<Enterprise> enterprise = enterpriseService.getEnterpriseById(updatedStage.getEnterprise().getId());
                if (enterprise.isEmpty()) {
                    return ResponseEntity.badRequest().body("Enterprise not found");
                }
                existingStage.setEnterprise(enterprise.get());
            }

            Stage savedStage = stageService.saveStage(existingStage);
            return ResponseEntity.ok(savedStage);
        } else {
            return ResponseEntity.notFound().build();
        }
    }
    //@PreAuthorize("hasRole('ROLE_ENTREPRISE') or hasRole('ROLE_ADMIN')")
    @DeleteMapping("/delete/{id}")
    public ResponseEntity<?> deleteStage(@PathVariable Long id) {
        Optional<Stage> optionalStage = stageService.getStageById(id);

        if (optionalStage.isPresent()) {
            stageService.deleteStage(id);
            return ResponseEntity.noContent().build(); // HTTP 204 No Content (successful deletion)
        } else {
            return ResponseEntity.notFound().build(); // HTTP 404 Not Found if the stage doesn't exist
        }
    }


}
