package com.example.gestionstagesbackend.controllers;

import com.example.gestionstagesbackend.model.Candidacy;
import com.example.gestionstagesbackend.model.Student;
import com.example.gestionstagesbackend.services.CandidacyService;
import com.example.gestionstagesbackend.services.StudentService;
import org.springframework.http.ResponseEntity;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/api/students")
@CrossOrigin(origins = "http://localhost:3000", allowCredentials = "true")
public class StudentController {
    private final StudentService studentService;
    private final CandidacyService candidacyService;

    public StudentController(StudentService studentService, CandidacyService candidacyService) {
        this.studentService = studentService;
        this.candidacyService = candidacyService;
    }

    //@PreAuthorize("hasRole('ROLE_SUPERVISEUR') or hasRole('ROLE_ADMIN')")
    @PostMapping("/add")
    public ResponseEntity<Student> createStudent(@RequestBody Student student) {
        Student savedStudent = studentService.saveStudent(student);
        return ResponseEntity.ok(savedStudent);
    }

    //@PreAuthorize("hasRole('ROLE_SUPERVISEUR') or hasRole('ROLE_ETUDIANT') or hasRole('ROLE_ADMIN')")
    @GetMapping
    public ResponseEntity<List<Student>> getAllStudents() {
        return ResponseEntity.ok(studentService.getAllStudents());
    }

    //@PreAuthorize("hasRole('ROLE_SUPERVISEUR') or hasRole('ROLE_ETUDIANT') or hasRole('ROLE_ADMIN')")
    @GetMapping("/{id}")
    public ResponseEntity<Student> getStudentById(@PathVariable Long id) {
        return studentService.getStudentById(id)
                .map(ResponseEntity::ok)
                .orElse(ResponseEntity.notFound().build());
    }

    // Endpoint to get all candidacies of a student
    @GetMapping("/{id}/candidacies")
    public ResponseEntity<List<Candidacy>> getStudentCandidacies(@PathVariable Long id) {
        List<Candidacy> candidacies = candidacyService.getCandidaciesByStudentId(id);
        return ResponseEntity.ok(candidacies);
    }

    //@PreAuthorize("hasRole('ROLE_SUPERVISEUR') or hasRole('ROLE_ADMIN')")
    @PutMapping("/update/{id}")
    public ResponseEntity<Student> updateStudent(@PathVariable Long id, @RequestBody Student updatedStudent) {
        Optional<Student> optionalStudent = studentService.getStudentById(id);

        if (optionalStudent.isPresent()) {
            Student existingStudent = optionalStudent.get();
            existingStudent.setFirstname(updatedStudent.getFirstname());
            existingStudent.setLastname(updatedStudent.getLastname());

            Student savedStudent = studentService.saveStudent(existingStudent);
            return ResponseEntity.ok(savedStudent);
        } else {
            return ResponseEntity.notFound().build();
        }
    }

    // ✅ DELETE - Remove student by ID
    @DeleteMapping("/delete/{id}")
    public ResponseEntity<Void> deleteStudent(@PathVariable Long id) {
        studentService.deleteStudent(id);
        return ResponseEntity.noContent().build();
    }
    @GetMapping("/with-role")
    public ResponseEntity<List<Student>> getStudentsWithRoleEtudiant() {
        List<Student> students = studentService.getStudentsByRole("ROLE_ETUDIANT");
        return ResponseEntity.ok(students);
    }

}
