package com.example.gestionstagesbackend.controllers;

import com.example.gestionstagesbackend.model.UnivSupervisor;
import com.example.gestionstagesbackend.services.UnivSupervisorService;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
@RequestMapping("/api/univsupervisors")
@CrossOrigin(origins = "http://localhost:3000", allowCredentials = "true")
public class UnivSupervisorController {
    private final UnivSupervisorService univSupervisorService;

    public UnivSupervisorController(UnivSupervisorService univSupervisorService) {
        this.univSupervisorService = univSupervisorService;
    }

    @PostMapping("/add")
    public ResponseEntity<UnivSupervisor> createUnivSupervisor(@RequestBody UnivSupervisor univSupervisor) {
        UnivSupervisor savedUnivSupervisor = univSupervisorService.saveUnivSupervisor(univSupervisor);
        return ResponseEntity.ok(savedUnivSupervisor);
    }

    @GetMapping
    public ResponseEntity<List<UnivSupervisor>> getAllUnivSupervisors() {
        return ResponseEntity.ok(univSupervisorService.getAllUnivSupervisors());
    }

    @GetMapping("/{id}")
    public ResponseEntity<UnivSupervisor> getUnivSupervisorById(@PathVariable Long id) {
        return univSupervisorService.getUnivSupervisorById(id)
                .map(ResponseEntity::ok)
                .orElse(ResponseEntity.notFound().build());
    }

    // ✅ PUT - Update UnivSupervisor by ID
    @PutMapping("/update/{id}")
    public ResponseEntity<UnivSupervisor> updateUnivSupervisor(@PathVariable Long id, @RequestBody UnivSupervisor updatedSupervisor) {
        Optional<UnivSupervisor> optionalSupervisor = univSupervisorService.getUnivSupervisorById(id);

        if (optionalSupervisor.isPresent()) {
            UnivSupervisor existingSupervisor = optionalSupervisor.get();
            existingSupervisor.setName(updatedSupervisor.getName());

            UnivSupervisor savedSupervisor = univSupervisorService.saveUnivSupervisor(existingSupervisor);
            return ResponseEntity.ok(savedSupervisor);
        } else {
            return ResponseEntity.notFound().build();
        }
    }

    // ✅ DELETE - Remove UnivSupervisor by ID
    @DeleteMapping("/delete/{id}")
    public ResponseEntity<Void> deleteUnivSupervisor(@PathVariable Long id) {
        univSupervisorService.deleteUnivSupervisor(id);
        return ResponseEntity.noContent().build();
    }
}
