package com.example.gestionstagesbackend.model;

import com.example.gestionstagesbackend.enums.AcceptedCandidacyStateKind;
import com.example.gestionstagesbackend.enums.CandidacyRequestState;
import com.fasterxml.jackson.annotation.JsonBackReference;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import jakarta.persistence.*;

@Entity
public class Candidacy {
    @Id
    @GeneratedValue(strategy = GenerationType.IDENTITY)
    private Long id;

    @ManyToOne
    @JoinColumn(name = "student_id")
    @JsonIgnoreProperties({"candidacies"}) // Prevents recursion, but keeps other data
    private Student student;

    @ManyToOne
    @JoinColumn(name = "stage_id", nullable = false)
    @JsonIgnoreProperties({"candidacies"}) // Ensures that Candidacy includes Stage but avoids loops
    private Stage stage;

    // suppression de @JsonIgnoreProperties pour inclure Stage in response

    @ManyToOne
    @JoinColumn(name = "univ_supervisor_id")
    @JsonIgnoreProperties({"supervisedStages"}) // Prevents recursion
    private UnivSupervisor univSupervisor;

    // Enum to store the request state (FirstRequest, Accepted, Declined)
    @Enumerated(EnumType.STRING)
    private CandidacyRequestState requestState = CandidacyRequestState.FirstRequest;

    // Enum to store the accepted candidacy state (wait, inProgress, terminated)
    @Enumerated(EnumType.STRING)
    private AcceptedCandidacyStateKind acceptedState = AcceptedCandidacyStateKind.wait;
    // Ajout du champ commentaire
    @Column(length = 500) // Définit une longueur max
    private String comment;

    public Candidacy() {}

    public Candidacy(Student student, Stage stage, UnivSupervisor univSupervisor) {
        this.student = student;
        this.stage = stage;
        this.univSupervisor = univSupervisor;
        this.requestState = CandidacyRequestState.FirstRequest; // Default state
        this.acceptedState = AcceptedCandidacyStateKind.wait;  // Default state
        this.comment = comment;
    }

    public Long getId() { return id; }
    public void setId(Long id) { this.id = id; }

    public Student getStudent() { return student; }
    public void setStudent(Student student) { this.student = student; }

    public Stage getStage() { return stage; }
    public void setStage(Stage stage) { this.stage = stage; }

    public UnivSupervisor getUnivSupervisor() { return univSupervisor; }
    public void setUnivSupervisor(UnivSupervisor univSupervisor) { this.univSupervisor = univSupervisor; }

    public CandidacyRequestState getRequestState() { return requestState; }
    public void setRequestState(CandidacyRequestState requestState) { this.requestState = requestState; }

    public AcceptedCandidacyStateKind getAcceptedState() { return acceptedState; }
    public void setAcceptedState(AcceptedCandidacyStateKind acceptedState) { this.acceptedState = acceptedState; }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

}
