package com.example.gestionstagesbackend.services;

import com.example.gestionstagesbackend.model.Enterprise;
import com.example.gestionstagesbackend.repositories.EnterpriseRepository;
import org.springframework.stereotype.Service;
import java.util.List;
import java.util.Optional;

@Service
public class EnterpriseService {

    private final EnterpriseRepository enterpriseRepository;

    public EnterpriseService(EnterpriseRepository enterpriseRepository) {
        this.enterpriseRepository = enterpriseRepository;
    }

    public Enterprise saveEnterprise(Enterprise enterprise) {
        //System.out.println("Saving enterprise: " + enterprise.getName() + ", " + enterprise.getAddress());

        // If stages exist, set their enterprise reference correctly
        if (enterprise.getStages() != null && !enterprise.getStages().isEmpty()) {
            enterprise.getStages().forEach(stage -> stage.setEnterprise(enterprise));
        } else {
            enterprise.setStages(null); // Avoid redundant or circular references
        }

        Enterprise savedEnterprise = enterpriseRepository.save(enterprise);
        System.out.println("Saved Enterprise ID: " + savedEnterprise.getId());

        return savedEnterprise;
    }

    public List<Enterprise> getAllEnterprises() {
        return enterpriseRepository.findAll();
    }

    public Optional<Enterprise> getEnterpriseById(Long id) {
        return enterpriseRepository.findByIdWithStages(id);
    }

    public void deleteEnterprise(Long id) {
        System.out.println("Deleting Enterprise ID: " + id);
        enterpriseRepository.deleteById(id);
    }
}
