package com.example.gestionstagesbackend.services;

import com.example.gestionstagesbackend.model.Student;
import com.example.gestionstagesbackend.repositories.StudentRepository;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class StudentService {
    private final StudentRepository studentRepository;

    public StudentService(StudentRepository studentRepository) {
        this.studentRepository = studentRepository;
    }

    public Student saveStudent(Student student) {
        return studentRepository.save(student);
    }

    public List<Student> getAllStudents() {
        return studentRepository.findAll();
    }

    public Optional<Student> getStudentById(Long id) {
        return studentRepository.findById(id);
    }

    public void deleteStudent(Long id) {
        if (studentRepository.existsById(id)) {
            studentRepository.deleteById(id);
        } else {
            throw new IllegalArgumentException("Student with ID " + id + " does not exist.");
        }
    }
    public void createStudentIfNotExists(String firstname, String lastname) {
        if (studentRepository.findByFirstnameAndLastname(firstname, lastname).isEmpty()) {
            Student student = new Student();
            student.setFirstname(firstname);
            student.setLastname(lastname);
            studentRepository.save(student);
            System.out.println("✅ Created student: " + firstname + " " + lastname);
        }
    }

    public List<Student> getStudentsByRole(String role) {
        return studentRepository.findStudentsByRole(role);
    }
}
